from django.template import TemplateSyntaxError
from django.template.loader import render_to_string
from wagtail.models import Site


def meta_tags(request, model):
    if not request:
        raise TemplateSyntaxError(
            "'meta_tags' missing request from context")
    if not model:
        raise TemplateSyntaxError(
            "'meta_tags' tag is missing a model or object")
    context = {
        'site_name': Site.find_for_request(request).site_name,
        'twitter_card_type': model.get_twitter_card_type(request),
        'object': model,
    }

    meta_image = model.get_meta_image_url(request)
    if meta_image:
        width, height = model.get_meta_image_dimensions()
        context['meta_image_width'] = width
        context['meta_image_height'] = height
    context['meta_image'] = meta_image

    return render_to_string('wagtailmetadata/parts/tags.html',
                            context, request=request)



from django.test import TestCase
from wagtail.images.models import Image
from wagtail.images.tests.utils import get_test_image_file
from wagtail.models import Site

from tests.app.models import TestPage


class TestMetadataPageMixin(TestCase):
    def setUp(self):
        self.site = Site.objects.first()
        self.site.site_name = 'Example site'
        self.site.save()

        self.image = Image.objects.create(
            title='Test Image',
            file=get_test_image_file(),
        )
        self.page = self.site.root_page.add_child(instance=TestPage(
            title='Test Page',
            search_image=self.image,
            search_description='Some test content description',
        ))

    def test_title(self):
        self.assertEqual(
            self.page.get_meta_title(),
            'Test Page')

    def test_url(self):
        self.assertEqual(
            self.page.get_meta_url(),
            'http://localhost/test-page/')

    def test_description(self):
        self.assertEqual(
            self.page.get_meta_description(),
            'Some test content description')

    def test_image(self):
        self.assertEqual(
            self.page.get_meta_image(),
            self.image)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-01 05:32


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmetadata', '0005_metadatasettings'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='metadatasettings',
            name='site',
        ),
        migrations.DeleteModel(
            name='MetadataSettings',
        ),
    ]



from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy
from wagtail.admin.panels import FieldPanel, MultiFieldPanel

from .utils import get_image_model_string


class MetadataMixin(object):
    """
    An object that can be shared on social media.
    """

    def get_meta_url(self):
        """The full URL to this object, including protocol and domain."""
        raise NotImplementedError()

    def get_meta_title(self):
        raise NotImplementedError()

    def get_object_title(self):
        return self.get_meta_title()

    def get_meta_description(self):
        raise NotImplementedError()

    def get_meta_image_url(self, request):
        """
        Get the image url to use for this object.
        Can be None if there is no relevant image.
        """
        return None

    def get_meta_image_dimensions(self):
        """
        Return width, height (in pixels)
        """
        return None, None

    def get_twitter_card_type(self, request):
        """
        Get the Twitter card type for this object.
        See https://dev.twitter.com/cards/types.
        Defaults to 'summary' if the object has an image,
        otherwise 'summary'.
        """
        if self.get_meta_image_url(request) is not None:
            return 'summary_large_image'
        else:
            return 'summary'


class WagtailImageMetadataMixin(MetadataMixin):
    """
    Subclass of MetadataMixin that uses a Wagtail Image for the image-based metadata
    """
    def get_meta_image(self):
        raise NotImplementedError()

    def get_meta_image_rendition(self):
        meta_image = self.get_meta_image()
        if meta_image:
            filter = getattr(settings, "WAGTAILMETADATA_IMAGE_FILTER", "original")
            rendition = meta_image.get_rendition(filter=filter)
            return rendition
        return None

    def get_meta_image_url(self, request):
        meta_image = self.get_meta_image_rendition()
        if meta_image:
            return request.build_absolute_uri(meta_image.url)
        return None

    def get_meta_image_dimensions(self):
        meta_image = self.get_meta_image_rendition()
        if meta_image:
            return meta_image.width, meta_image.height
        return None, None


class MetadataPageMixin(WagtailImageMetadataMixin, models.Model):
    """An implementation of MetadataMixin for Wagtail pages."""
    search_image = models.ForeignKey(
        get_image_model_string(),
        null=True,
        blank=True,
        related_name='+',
        on_delete=models.SET_NULL,
        verbose_name=gettext_lazy('Search image')
    )

    promote_panels = [
        MultiFieldPanel([
            FieldPanel('slug'),
            FieldPanel('seo_title'),
            FieldPanel('show_in_menus'),
            FieldPanel('search_description'),
            FieldPanel('search_image'),
        ], gettext_lazy('Common page configuration')),
    ]

    def get_meta_url(self):
        return self.full_url

    def get_meta_title(self):
        return self.seo_title or self.title

    def get_meta_description(self):
        return self.search_description

    def get_meta_image(self):
        return self.search_image

    class Meta:
        abstract = True



#!/usr/bin/env python
"""
Install wagtail-metadata using setuptools
"""

from setuptools import find_packages, setup

with open("README.rst", "r") as f:
    readme = f.read()

setup(
    name="wagtail-metadata",
    version="4.0.3",
    description="A tool to assist with metadata for social media.",
    long_description=readme,
    author="Neon Jungle",
    author_email="developers@neonjungle.studio",
    url="https://github.com/neon-jungle/wagtail-metadata",
    install_requires=[
        "wagtail>=3.0",
    ],
    zip_safe=False,
    license="BSD License",
    python_requires=">=3",
    packages=find_packages(exclude=["tests", "tests*"]),
    include_package_data=True,
    package_data={},
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Framework :: Django",
        "License :: OSI Approved :: BSD License",
    ],
)



import jinja2
import markupsafe
from jinja2.ext import Extension

from wagtailmetadata import tags


@jinja2.pass_context
def meta_tags(context, model=None):
    request = context.get('request', None)
    if not model:
        model = context.get('page', None)

    return markupsafe.Markup(tags.meta_tags(request, model))


class WagtailMetadataExtension(Extension):
    def __init__(self, environment):
        super(WagtailMetadataExtension, self).__init__(environment)

        self.environment.globals.update({
            'meta_tags': meta_tags,
        })
